@@ -1,4 +1,4 @@
-/* $Id: gdict-about.c,v 1.18 2003/12/31 21:17:09 gman Exp $ */
+/* $Id: gdict-about.c,v 1.19 2004/02/12 09:14:34 dsmit Exp $ */
 
 /*
  *  Papadimitriou Spiros <spapadim+@cs.cmu.edu>
@@ -24,7 +24,7 @@
 #include "gdict-about.h"
 
 
-static GtkWidget *gdict_about_new (void)
+GtkWidget *gdict_about_new (void)
 {
     GdkPixbuf   *pixbuf = NULL;
     GError  	*error = NULL;
