@@ -1,4 +1,4 @@
-/* $Id: gdict-app.c,v 1.62 2003/11/10 01:49:50 gman Exp $ */
+/* $Id: gdict-app.c,v 1.65 2004/05/11 23:23:28 fherrera Exp $ */
 /* -*- mode: c; style: k&r; c-basic-offset: 4 -*- */
 
 /*
@@ -63,6 +63,8 @@ GnomePrinter *gdict_printer = NULL;
 dict_context_t *context;
 
 static void gdict_edit_menu_set_sensitivity (gboolean flag);
+static void follow_if_link (GtkWidget *defbox, GtkTextIter *iter);
+
 
 static void
 socket_error_cb (GtkWidget *widget, gchar *message, gpointer data) 
@@ -208,7 +210,7 @@ gdict_app_do_lookup (gchar *text)
     word_entry_text = gtk_editable_get_chars (GTK_EDITABLE (word_entry), 0, -1);
     if ((word_entry_text == NULL) || (*word_entry_text == 0) || (strcmp (word_entry_text, text) != 0))
     {
-        g_strdown (text);
+        g_utf8_strdown (text, strlen (text));
         gnome_entry_prepend_history (GNOME_ENTRY (gnome_word_entry), 1, text);
         gtk_entry_set_text (GTK_ENTRY (word_entry), text);
     }
@@ -232,7 +234,7 @@ static void
 lookup_entry (void) 
 {
     gchar *text = gtk_editable_get_chars (GTK_EDITABLE (word_entry), 0, -1);
-    g_strdown(text);
+    g_utf8_strdown(text, strlen (text));
     gdict_app_do_lookup (text);
     if (text)
         g_free (text);
@@ -246,7 +248,7 @@ lookup_defbox (void)
     gtk_entry_set_text (GTK_ENTRY (word_entry), "");
     gtk_signal_emit_by_name (GTK_OBJECT (word_entry), "paste_clipboard");
     text = gtk_editable_get_chars (GTK_EDITABLE (word_entry), 0, -1);
-    g_strdown (text);
+    g_utf8_strdown (text, strlen (text));
     gnome_entry_prepend_history (GNOME_ENTRY (gnome_word_entry), 1, text);
     gdict_app_do_lookup (text);
     if (text)
@@ -323,7 +325,7 @@ lookup_button_drag_cb (GtkWidget *widget, GdkDragContext *context, gint x, gint
 	text = gtk_selection_data_get_text (sd);
 	
 	if (text) {
-		g_strdown (text);
+		g_utf8_strdown (text, strlen (text));
 		gtk_entry_set_text (GTK_ENTRY (word_entry), text);
     		gnome_entry_prepend_history (GNOME_ENTRY (gnome_word_entry), 1, text);
     		gdict_app_do_lookup (text);
@@ -474,7 +476,7 @@ find_cb (GtkMenuItem *menuitem, gpointer user_data)
 					  NULL);
     	hbox = gtk_hbox_new (FALSE, 8);
 	
-    	label = gtk_label_new_with_mnemonic ("_Search for:");
+    	label = gtk_label_new_with_mnemonic (_("_Search for:"));
     
     	entry = gtk_entry_new ();
    	gtk_entry_set_activates_default (GTK_ENTRY (entry), TRUE);
@@ -755,6 +757,151 @@ enum
   TARGET_TEXT_BUFFER_CONTENTS
 };
 
+
+static gboolean
+event_after (GtkWidget *defbox,
+	     GdkEvent  *ev)
+{
+  GtkTextIter start, end, iter;
+  GtkTextBuffer *buffer;
+  GdkEventButton *event;
+  gint x, y;
+  if (ev->type != GDK_BUTTON_RELEASE)
+    return FALSE;
+
+  event = (GdkEventButton *)ev;
+
+  if (event->button != 1)
+    return FALSE;
+
+  buffer = gtk_text_view_get_buffer (GTK_TEXT_VIEW (defbox));
+
+  gtk_text_buffer_get_selection_bounds (buffer, &start, &end);
+  if (gtk_text_iter_get_offset (&start) != gtk_text_iter_get_offset (&end))
+    return FALSE;
+
+  gtk_text_view_window_to_buffer_coords (GTK_TEXT_VIEW (defbox), 
+                                         GTK_TEXT_WINDOW_WIDGET,
+                                         event->x, event->y, &x, &y);
+
+  gtk_text_view_get_iter_at_location (GTK_TEXT_VIEW (defbox), &iter, x, y);
+
+  follow_if_link (defbox, &iter);
+
+  return FALSE;
+}
+
+static void
+follow_if_link (GtkWidget   *defbox, 
+		GtkTextIter *iter)
+{
+  GSList *tags = NULL, *tagp = NULL;
+  gchar *str;
+
+  tags = gtk_text_iter_get_tags (iter);
+  for (tagp = tags;  tagp != NULL;  tagp = tagp->next)
+    {
+      GtkTextTag *tag = tagp->data;
+      str = g_object_get_data (G_OBJECT (tag), "page");
+      gdict_defbox_clear (GDICT_DEFBOX (defbox));		
+      gdict_app_do_lookup (str);
+      gtk_widget_grab_focus (word_entry);
+      gtk_editable_set_position (GTK_EDITABLE (word_entry), -1);
+      g_free (str);
+    }
+  if (tags) 
+    g_slist_free (tags);
+}
+
+
+
+gboolean hovering_over_link = FALSE;
+GdkCursor *hand_cursor = NULL;
+GdkCursor *regular_cursor = NULL;
+
+
+static void
+set_cursor_if_appropriate (GtkWidget *defbox,
+                           gint            x,
+                           gint            y)
+{
+  GSList *tags = NULL, *tagp = NULL;
+  GtkTextBuffer *buffer;
+  GtkTextIter iter;
+  gboolean hovering = FALSE;
+	
+   hand_cursor = gdk_cursor_new (GDK_HAND2);
+   regular_cursor = gdk_cursor_new (GDK_XTERM);
+   
+  buffer = gtk_text_view_get_buffer (GTK_TEXT_VIEW (defbox));
+
+  gtk_text_view_get_iter_at_location (GTK_TEXT_VIEW (defbox), &iter, x, y);
+  
+  tags = gtk_text_iter_get_tags (&iter);
+  for (tagp = tags;  tagp != NULL;  tagp = tagp->next)
+    {
+      GtkTextTag *tag = tagp->data;
+	  gint page = GPOINTER_TO_INT (g_object_get_data (G_OBJECT (tag), "page"));
+      
+      if (page != 0) 
+        {
+          hovering = TRUE;
+          break;
+        }
+    }
+
+  if (hovering != hovering_over_link)
+    {
+      hovering_over_link = hovering;
+
+      if (hovering_over_link)
+        gdk_window_set_cursor (gtk_text_view_get_window (GTK_TEXT_VIEW (defbox), GTK_TEXT_WINDOW_TEXT), hand_cursor);
+      else
+        gdk_window_set_cursor (gtk_text_view_get_window (GTK_TEXT_VIEW (defbox), GTK_TEXT_WINDOW_TEXT), regular_cursor);
+    }
+
+  if (tags) 
+    g_slist_free (tags);
+}
+
+static gboolean
+motion_notify_event ( GtkWidget *defbox,
+		     GdkEventMotion *event)
+{
+  gint x, y;
+  
+  
+  gtk_text_view_window_to_buffer_coords (GTK_TEXT_VIEW (defbox), 
+                                         GTK_TEXT_WINDOW_WIDGET,
+                                         event->x, event->y, &x, &y);
+
+  
+  set_cursor_if_appropriate (defbox, x, y);
+  gdk_window_get_pointer (GTK_WIDGET(defbox)->window, NULL, NULL, NULL);
+  return FALSE;
+}
+
+/* update the cursor image if the window becomes visible */
+ 
+static gboolean
+visibility_notify_event (GtkWidget *defbox,
+			 GdkEventVisibility *event)
+{
+  gint wx, wy, bx, by;
+  
+  
+  gdk_window_get_pointer (GTK_WIDGET(defbox)->window, &wx, &wy, NULL);
+  
+  gtk_text_view_window_to_buffer_coords (GTK_TEXT_VIEW (defbox), 
+                                         GTK_TEXT_WINDOW_WIDGET,
+                                         wx, wy, &bx, &by);
+
+  set_cursor_if_appropriate (defbox, bx, by);
+  return FALSE;
+}
+
+
+
 GtkWidget *gdict_app_create (gboolean applet) {
     GtkWidget *dock;
     GtkWidget *vbox;
@@ -867,14 +1014,28 @@ GtkWidget *gdict_app_create (gboolean applet) {
     gtk_widget_show (gdict_appbar);
 
     if (!applet)
-      gtk_signal_connect (GTK_OBJECT (gdict_app), "delete_event",
-                          GTK_SIGNAL_FUNC (gtk_main_quit), NULL);
+      g_signal_connect (gdict_app, "delete_event",
+                        G_CALLBACK (gtk_main_quit), NULL);
     else
-      gtk_signal_connect (GTK_OBJECT (gdict_app), "delete_event",
-                          GTK_SIGNAL_FUNC (gtk_widget_hide), NULL);
+      g_signal_connect (gdict_app, "delete_event",
+                        G_CALLBACK (gtk_widget_hide), NULL);
     
-    gtk_signal_connect (GTK_OBJECT (word_entry), "activate",
-                        GTK_SIGNAL_FUNC(lookup_cb), NULL);
+    g_signal_connect (word_entry, "activate",
+                      G_CALLBACK (lookup_cb), NULL);
+	
+    gtk_widget_realize (GTK_WIDGET (defbox));
+	
+    g_signal_connect (defbox, "event-after", 
+		      G_CALLBACK (event_after), NULL);
+    
+    g_signal_connect (defbox, "motion-notify-event", 
+		      G_CALLBACK (motion_notify_event), NULL);
+    
+    g_signal_connect (defbox, "visibility-notify-event", 
+		      G_CALLBACK (visibility_notify_event), NULL);
+    
+    gtk_widget_show (GTK_WIDGET (defbox));
+	
     return gdict_app;
 }
 
