@@ -1,4 +1,4 @@
-/* $Id: gdict-applet.c,v 1.51 2003/12/31 21:17:09 gman Exp $ */
+/* $Id: gdict-applet.c,v 1.58 2004/05/08 01:59:49 gman Exp $ */
 
 /*
  *  Papadimitriou Spiros <spapadim+@cs.cmu.edu>
@@ -56,19 +56,24 @@ button_press_hack (GtkWidget *w, GdkEventButton *event, gpointer data)
 static void
 entry_activate_cb (GtkEntry *entry, gpointer data)
 {
-    	gchar *text = gtk_editable_get_chars (GTK_EDITABLE (entry), 0, -1);
+	GDictApplet *applet = data;
+
+	gchar *text = gtk_editable_get_chars (GTK_EDITABLE (entry), 0, -1);
     
     	if (!context)
 		gdict_init_context ();
     	if (!GTK_WIDGET_VISIBLE (gdict_app))
         	gtk_widget_show (gdict_app);
-    
+   
+	gtk_window_set_screen (GTK_WINDOW (gdict_app),
+			       gtk_widget_get_screen (applet->applet_widget));
+	
     	gtk_window_present (GTK_WINDOW (gdict_app));
     
     	if (!text || *text == 0)
         	return;
         
-    	g_strdown (text);
+    	g_utf8_strdown (text, strlen (text));
 	gtk_editable_delete_text (GTK_EDITABLE (entry), 0, -1);
     	gdict_app_do_lookup (text);
     	g_free (text);
@@ -114,11 +119,14 @@ setup_applet_widgets (GDictApplet *applet)
     	};
 	
 	gboolean use_horizontal = TRUE;
-	
+
+
+	applet->about_dialog = NULL;
+
 	if (applet->box) {
 		gtk_widget_destroy (applet->box);
 	}
-		
+
 	if ((applet->orient == PANEL_APPLET_ORIENT_LEFT || applet->orient == PANEL_APPLET_ORIENT_RIGHT) || 
 	    ((applet->orient == PANEL_APPLET_ORIENT_UP || applet->orient == PANEL_APPLET_ORIENT_DOWN) && applet->panel_size >= 48)) {
 		use_horizontal = FALSE;
@@ -143,6 +151,9 @@ setup_applet_widgets (GDictApplet *applet)
         add_atk_namedesc (GTK_WIDGET (applet->button_widget), _("Dictionary Lookup"), NULL);
 
 	applet->entry_widget = gtk_entry_new ();
+	if (GTK_IS_ACCESSIBLE (gtk_widget_get_accessible (applet->entry_widget)))
+		add_atk_namedesc (GTK_WIDGET (applet->entry_widget), _("Dictionary word entry"), NULL);
+
 	gtk_entry_set_width_chars (GTK_ENTRY (applet->entry_widget), 12);
 	gtk_box_pack_start (GTK_BOX (applet->box), applet->entry_widget, FALSE, FALSE, 0);
 
@@ -223,6 +234,20 @@ send_button_to_entry_event (GtkWidget *widget, GdkEventButton *event, GDictApple
 	return FALSE;
 }
 
+static gboolean
+destroy_applet (GtkWidget *widget, gpointer data)
+{
+	GDictApplet *applet = data;
+
+	if (applet->about_dialog)
+		gtk_widget_destroy (applet->about_dialog);
+
+	gtk_widget_destroy (applet->button_widget);
+	gtk_widget_destroy (applet->box);
+	gtk_widget_destroy (applet->entry_widget);
+	gtk_widget_destroy (applet->applet_widget);
+}
+
 static void 
 menu_event_cb (BonoboUIComponent            *comp,
                const gchar                  *path,
@@ -261,7 +286,7 @@ text_received (GtkClipboard *clipboard, const gchar *text, gpointer data)
 	
 	if (*lookup_text == 0)
         	return;
-    	g_strdown (lookup_text);
+    	g_utf8_strdown (lookup_text, strlen(lookup_text));
     	gtk_entry_set_text (GTK_ENTRY (applet->entry_widget), text);
     	entry_activate_cb (GTK_ENTRY (applet->entry_widget), applet);
 #if 0    	
@@ -288,7 +313,25 @@ about_cb (BonoboUIComponent *uic,
           gpointer           user_data,
           const gchar       *verbname)
 {
-	gdict_about(NULL);
+	GDictApplet *applet = user_data;
+
+	if (applet->about_dialog) {
+		gtk_window_set_screen (GTK_WINDOW (applet->about_dialog),
+				       gtk_widget_get_screen (applet->applet_widget));
+
+		gtk_window_present (GTK_WINDOW (applet->about_dialog));
+		return;
+	}
+
+	applet->about_dialog = gdict_about_new ();
+
+	gtk_window_set_screen (GTK_WINDOW (applet->about_dialog),
+			       gtk_widget_get_screen (applet->applet_widget));
+
+	g_signal_connect (G_OBJECT (applet->about_dialog), "destroy",
+			  G_CALLBACK (gtk_widget_destroyed), &applet->about_dialog);
+
+	gtk_widget_show (applet->about_dialog);
 }
 
 static void
@@ -327,6 +370,7 @@ prefs_cb (BonoboUIComponent *uic,
 {
 	if (!context)
 		gdict_init_context ();
+
 	gdict_app_show_preferences ();
 }
 
@@ -345,7 +389,8 @@ gdict_applet_new (PanelApplet *parent_applet)
 	GDictApplet *applet;
 	BonoboUIComponent *component;
 	GtkIconInfo *icon_info;
- 	
+	GtkTooltips *tooltips;
+
  	applet = g_new0 (GDictApplet, 1);
  	
 	applet->applet_widget = GTK_WIDGET(parent_applet);
@@ -366,6 +411,15 @@ gdict_applet_new (PanelApplet *parent_applet)
  	
  	gdict_app_create (TRUE);
  	
+	tooltips = gtk_tooltips_new ();
+	g_object_ref (tooltips);
+	gtk_object_sink (GTK_OBJECT (tooltips));
+	g_object_set_data_full (G_OBJECT (applet->applet_widget), "tooltips",
+				tooltips, (GDestroyNotify) g_object_unref);
+
+	gtk_tooltips_set_tip (tooltips, applet->applet_widget,
+			      _("Lookup words in an online dictionary"), NULL);
+
  	panel_applet_setup_menu_from_file (PANEL_APPLET (applet->applet_widget),
 					   NULL,
                             		   "GNOME_GDictApplet.xml",
@@ -373,10 +427,10 @@ gdict_applet_new (PanelApplet *parent_applet)
                             		   gdict_applet_menu_verbs,
                             		   applet);                               
 
-	if (panel_applet_get_locked_down (PANEL_APPLET (applet))) {
+	if (panel_applet_get_locked_down (PANEL_APPLET (applet->applet_widget))) {
 		BonoboUIComponent *popup_component;
 
-		popup_component = panel_applet_get_popup_component (PANEL_APPLET (applet));
+		popup_component = panel_applet_get_popup_component (PANEL_APPLET (applet->applet_widget));
 
 		bonobo_ui_component_set_prop (popup_component,
 					      "/commands/prefs",
@@ -398,7 +452,9 @@ gdict_applet_new (PanelApplet *parent_applet)
 			  G_CALLBACK (send_button_to_entry_event), applet); 
  	g_signal_connect (G_OBJECT (applet->applet_widget), "button_press_event",                         
 			  G_CALLBACK (set_show_dictionary_menu_state), NULL);
- 	
+	g_signal_connect (G_OBJECT (applet->applet_widget), "destroy",
+			  G_CALLBACK (destroy_applet), applet);
+
 	return TRUE;
 }
 
