@@ -1,4 +1,4 @@
-/* $Id: gdict-speller.c,v 1.23 2003/05/31 05:54:47 dcransto Exp $ */
+/* $Id: gdict-speller.c,v 1.25 2004/05/08 01:57:09 gman Exp $ */
 
 /*
  *  Mike Hughes <mfh@psilord.com>
@@ -145,7 +145,6 @@ gdict_speller_init (GDictSpeller *speller) {
     {
         add_atk_namedesc (label, _("Word"), _("Word"));
         add_atk_namedesc (GTK_WIDGET(speller->word_entry), _("Word Entry"), _("Enter a word to know the spelling"));
-        add_atk_relation (GTK_WIDGET(speller->word_entry), label, ATK_RELATION_LABELLED_BY);
     }
       
     speller->hbox = gtk_hbox_new (FALSE, 12);
@@ -280,17 +279,11 @@ gdict_speller_class_init (GDictSpellerClass *class) {
  */
 
 GtkWidget *
-gdict_speller_new (dict_context_t *context) {
-    GDictSpeller *speller;
-    
-    g_return_val_if_fail (context != NULL, NULL);
-    
-    speller = GDICT_SPELLER (gtk_type_new (gdict_speller_get_type ()));
-    speller->context = context;
-    
-    gdict_speller_reset_strat (speller);
-    
-    return GTK_WIDGET (speller);
+gdict_speller_new () {
+    GtkWidget	 *widget;
+ 
+    widget = g_object_new (gdict_speller_get_type (), NULL);
+    return widget;
 }
 
 /* gdict_speller_destroy
