@@ -58,6 +58,9 @@
 
 static GtkIconSize gsearchtool_icon_size = 0;
 
+struct _SearchStruct search_command;
+struct _InterfaceStruct interface;
+
 typedef struct _FindOptionTemplate FindOptionTemplate;
 struct _FindOptionTemplate {
 	SearchConstraintType type;
@@ -268,6 +271,7 @@ build_search_command (void)
 	gchar *file_is_named_utf8;
 	gchar *file_is_named_locale;
 	gchar *file_is_named_escaped;
+	gchar *file_is_named_backslashed;
 	gchar *look_in_folder_utf8;
 	gchar *look_in_folder_locale;
 
@@ -317,7 +321,9 @@ build_search_command (void)
 		gboolean disable_quick_search;
 		
 		locate = g_find_program_in_path ("locate");
-		file_is_named_escaped = escape_single_quotes (file_is_named_locale);
+		file_is_named_backslashed = backslash_backslashes (file_is_named_locale);
+		file_is_named_escaped = escape_single_quotes (file_is_named_backslashed);
+
 		search_command.file_is_named_pattern = g_strdup(file_is_named_utf8);
 		disable_quick_search = gsearchtool_gconf_get_boolean ("/apps/gnome-search-tool/disable_quick_search");
 		
@@ -347,7 +353,8 @@ build_search_command (void)
 		gboolean disable_mount_argument = FALSE;
 		
 		search_command.regex_matching_enabled = FALSE;
-		file_is_named_escaped = escape_single_quotes (file_is_named_locale);
+		file_is_named_backslashed = backslash_backslashes (file_is_named_locale);
+		file_is_named_escaped = escape_single_quotes (file_is_named_backslashed);
 		search_command.file_is_named_pattern = g_strdup(file_is_named_utf8);
 		
 		g_string_append_printf (command, "find \"%s\" '!' -type p  %s", 
@@ -374,23 +381,29 @@ build_search_command (void)
 			case SEARCH_CONSTRAINT_TEXT:
 				if (strcmp (templates[constraint->constraint_id].option, "-regex '%s'") == 0) {
 					
+					gchar *escaped;
 					gchar *regex;
 					
-					regex = escape_single_quotes (constraint->data.text);
+					escaped = backslash_backslashes (constraint->data.text);
+					regex = escape_single_quotes (escaped);
 					
 					if (regex != NULL) {	
 						search_command.regex_matching_enabled = TRUE;
 						search_command.regex_string = g_locale_from_utf8 (regex, -1, NULL, NULL, NULL);
 					}
 					
+					g_free (escaped);
 					g_free (regex);
 				} 
 				else {
-					gchar *string;
+					gchar *escaped;
+					gchar *backslashed;
 					gchar *locale;
 					
-					string = escape_single_quotes (constraint->data.text);
-					locale = g_locale_from_utf8 (string, -1, NULL, NULL, NULL);
+					backslashed = backslash_backslashes (constraint->data.text);
+					escaped = escape_single_quotes (backslashed);
+					
+					locale = g_locale_from_utf8 (escaped, -1, NULL, NULL, NULL);
 					
 					if (strlen (locale) != 0) { 
 						g_string_append_printf (command,
@@ -400,8 +413,9 @@ build_search_command (void)
 						g_string_append_c (command, ' ');
 					}
 					
-					g_free(string);
-					g_free(locale);					
+					g_free (escaped);
+					g_free (backslashed);
+					g_free (locale);					
 				}
 				break;
 			case SEARCH_CONSTRAINT_NUMBER:
@@ -436,6 +450,7 @@ build_search_command (void)
 		g_string_append (command, "-print ");
 	}
 	g_free (file_is_named_locale);
+	g_free (file_is_named_backslashed);
 	g_free (look_in_folder_locale);
 	
 	return g_string_free (command, FALSE);
@@ -1469,10 +1484,11 @@ create_constraint_box (SearchConstraint *opt, gchar *value)
 		
 		if (interface.is_gail_loaded)
 		{
-			add_atk_namedesc (GTK_WIDGET(entry), _("Search Rule Value Entry"), 
-					  _("Enter a value for search rule"));
-			add_atk_relation (entry, GTK_WIDGET(label), ATK_RELATION_LABELLED_BY);
-			add_atk_relation (GTK_WIDGET(label), entry, ATK_RELATION_LABEL_FOR);
+			gchar *text = remove_mnemonic_character (templates[opt->constraint_id].desc);
+			gchar *desc = g_strdup_printf (_("'%s' entry"), _(text));
+			add_atk_namedesc (GTK_WIDGET(entry), desc, _("Enter a value for search rule"));
+			g_free (desc);
+			g_free (text);
 		}
 		
 		gtk_label_set_mnemonic_widget (GTK_LABEL (label), GTK_WIDGET (entry));
@@ -1579,7 +1595,6 @@ create_additional_constraint_section (void)
 	{
 		add_atk_namedesc (GTK_WIDGET (interface.constraint_menu), _("Search Rules Menu"), 
 				  _("Select a search rule from the menu"));
-		add_atk_relation (interface.constraint_menu, GTK_WIDGET(label), ATK_RELATION_LABELLED_BY);
 	}
 
 	interface.add_button = gtk_button_new_from_stock (GTK_STOCK_ADD);
@@ -1806,7 +1821,7 @@ create_main_window (void)
 	gtk_table_attach (GTK_TABLE(interface.table), label, 0, 1, 0, 1, GTK_FILL, 0, 0, 1);
 
 	interface.file_is_named_entry = gnome_entry_new ("gsearchtool-file-entry");
-	gtk_label_set_mnemonic_widget (GTK_LABEL(label), gnome_entry_gtk_entry (GNOME_ENTRY(interface.file_is_named_entry)));
+	gtk_label_set_mnemonic_widget (GTK_LABEL(label), interface.file_is_named_entry);
 	gnome_entry_set_max_saved (GNOME_ENTRY(interface.file_is_named_entry), 10);
 	gtk_table_attach (GTK_TABLE(interface.table), interface.file_is_named_entry, 1, 2, 0, 1, GTK_EXPAND | GTK_FILL | GTK_SHRINK, 0, 0, 0);
 	entry =  gnome_entry_gtk_entry (GNOME_ENTRY(interface.file_is_named_entry));
@@ -1814,9 +1829,8 @@ create_main_window (void)
 	if (GTK_IS_ACCESSIBLE (gtk_widget_get_accessible(interface.file_is_named_entry)))
 	{
 		interface.is_gail_loaded = TRUE;
-		add_atk_namedesc (interface.file_is_named_entry, _("Name Contains Entry"), _("Enter the file name you want to search"));
+		add_atk_namedesc (interface.file_is_named_entry, NULL, _("Enter the file name you want to search"));
 		add_atk_namedesc (entry, _("Name Contains Entry"), _("Enter the file name you want to search"));
-		add_atk_relation (interface.file_is_named_entry, GTK_WIDGET(label), ATK_RELATION_LABELLED_BY);
 	}	
      
 	g_signal_connect (G_OBJECT (interface.file_is_named_entry), "activate",
@@ -1834,17 +1848,18 @@ create_main_window (void)
 	gtk_table_attach(GTK_TABLE(interface.table), label, 0, 1, 1, 2, GTK_FILL, 0, 0, 0);
 	
 	interface.look_in_folder_entry = gnome_file_entry_new ("gsearchtool-folder-entry", _("Browse"));
-	gnome_file_entry_set_directory_entry (GNOME_FILE_ENTRY(interface.look_in_folder_entry), TRUE);
+	gnome_file_entry_set_directory_entry (GNOME_FILE_ENTRY (interface.look_in_folder_entry), TRUE);
+	g_object_set (G_OBJECT (interface.look_in_folder_entry), "use-filechooser", TRUE, NULL);
+	
 	entry = gnome_file_entry_gtk_entry (GNOME_FILE_ENTRY(interface.look_in_folder_entry));
-	gtk_label_set_mnemonic_widget (GTK_LABEL(label), entry);
+	gtk_label_set_mnemonic_widget (GTK_LABEL(label), interface.look_in_folder_entry);
 	folder_entry = gnome_file_entry_gnome_entry (GNOME_FILE_ENTRY(interface.look_in_folder_entry));
 	gtk_table_attach (GTK_TABLE(interface.table), interface.look_in_folder_entry, 1, 2, 1, 2, GTK_EXPAND | GTK_FILL | GTK_SHRINK, 0, 0, 0);
 	
 	if (interface.is_gail_loaded)
 	{ 
-		add_atk_namedesc (GTK_WIDGET(folder_entry), _("Look in Folder Entry"), _("Enter the folder name where you want to start the search"));
+		add_atk_namedesc (GTK_WIDGET(folder_entry), NULL, _("Enter the folder name where you want to start the search"));
 		add_atk_namedesc (GTK_WIDGET(entry), _("Look in Folder Entry"), _("Enter the folder name where you want to start the search"));
-		add_atk_relation (folder_entry, GTK_WIDGET(label), ATK_RELATION_LABELLED_BY); 
 	}
 	
 	g_signal_connect (G_OBJECT (entry), "key_press_event",
