@@ -30,7 +30,7 @@
 
 #define MINIMUM_WINDOW_WIDTH   422
 #define MINIMUM_WINDOW_HEIGHT  310
-#define GNOME_SEARCH_TOOL_ICON  "gnome-searchtool.png"
+#define GNOME_SEARCH_TOOL_ICON  "gnome-searchtool"
 
 #ifdef __cplusplus
 extern "C" {
@@ -40,7 +40,7 @@ extern "C" {
 #include <gconf/gconf.h>
 #include <gconf/gconf-client.h>
 
-GConfClient * global_gconf_client;
+static GConfClient * global_gconf_client;
 
 typedef enum {
 	SEARCH_CONSTRAINT_END, 
@@ -72,10 +72,9 @@ typedef enum {
 	NUM_COLUMNS
 } ResultColumn;
 	  
-struct _SearchStruct {
+extern struct _SearchStruct {
 	gint			pid;
 	gint 	        	timeout;
-	gint			animation_timeout;
 	gchar			*look_in_folder;
 	gchar           	*file_is_named_pattern;
 	gchar 	  		*regex_string;
@@ -85,16 +84,17 @@ struct _SearchStruct {
 	gboolean		not_running_timeout;
 	gboolean		aborted;
 	RunStatus        	running;
+	GHashTable              *pixbuf_hash;
 } search_command;
 
-struct _InterfaceStruct {
+extern struct _InterfaceStruct {
 	GtkWidget		*file_is_named_entry;
 	GtkWidget 		*look_in_folder_entry;
 	GtkWidget		*find_button;
 	GtkWidget		*stop_button;
 	GtkWidget 		*save_button;
 	GtkWidget 		*main_window;	
-	GtkWidget		*drawing_area;
+	GtkWidget               *spinner;
 	GdkPixbuf		*pixbuf;	
 	GtkWidget		*table;	
 	GtkWidget 		*file_selector;
@@ -114,8 +114,6 @@ struct _InterfaceStruct {
 	GList 			*selected_constraints;
 	gchar 		 	*save_results_file;	
 	gint 		  	selected_constraint;
-	gint			current_animation_frame;
-	GnomeIconTheme	 	*icon_theme;
 	gboolean  	  	is_gail_loaded;
 } interface;
 
@@ -152,12 +150,6 @@ set_constraint_selected_state	(gint		constraint_id,
 void
 set_constraint_gconf_boolean 	(gint 		constraint_id, 
 				 gboolean 	flag);
-gboolean
-update_progress_bar 		(gpointer data);
-
-gboolean
-update_animation_timeout_cb 	(gpointer data);
-
 void
 set_clone_command		(gint *argcp,
 				 gchar ***argvp,
