@@ -99,13 +99,12 @@ static void iterate_thru_children(GtkTreeView  *tree_view,
 /**
  * Recursively called until the row specified by orig is found.
  *
- * *count will be set to the visible row number of the child
+ * *count will be set to the  row number of the child
  * relative to the row that was initially passed in as tree_path.
  *
- * *count will be -1 if orig is not found as a child (a row that is
- * not visible will not be found, e.g. if the row is inside a
- * collapsed row).  If NULL is passed in as orig, *count will
- * be a count of the visible children.
+ * *count will be -1 if orig is not found as a child.
+ * If NULL is passed in as orig, *count will
+ * be a count of the all the children (visible + collapsed (invisible)).
  *
  * NOTE: the value for depth must be 0 when this recursive function
  * is initially called, or it may not function as expected.
@@ -132,10 +131,8 @@ iterate_thru_children(GtkTreeView  *tree_view,
       *count = -1;
       return;
     }
-  else if (gtk_tree_view_row_expanded (tree_view, tree_path) && 
-    gtk_tree_model_iter_has_child (tree_model, &iter)) 
+  else if (gtk_tree_model_iter_has_child (tree_model, &iter))
     {
-      (*count)++;
       gtk_tree_path_append_index (tree_path, 0);
       iterate_thru_children (tree_view, tree_model, tree_path,
                              orig, count, (depth + 1));
@@ -228,7 +225,6 @@ void
 handle_row_activation_cb (GtkTreeView *treeview, GtkTreePath *path,
      GtkTreeViewColumn *arg2, gpointer user_data)
 {
-    GtkTreeIter iter;
     GtkTreeModel *model;
     GtkTreePath *root_tree;
     gint row = 0;
@@ -479,8 +475,8 @@ DrawLogLines (Log *current_log)
    GtkTreePath *path;
    LogLine *line;
    char tmp[4096];
-   char *utf8;
-   gint i = 0, count = 0;
+   char *utf8 = NULL;
+   gint i = 0;
    gint cm, cd;
 
    
@@ -504,6 +500,12 @@ DrawLogLines (Log *current_log)
                PROCESS, FALSE, MESSAGE, FALSE, -1);
            cm = line->month;
            cd = line->date;
+
+           /* store pointer to this date header, using the current
+            * month and day as the key */
+           g_hash_table_insert (current_log->date_headers,
+                        DATEHASH (cm, cd),
+                        gtk_tree_model_get_path (tree_model, &iter));
        }
        if (line->hour >= 0 && line->min >= 0 && line->sec >= 0) {
 	       struct tm date = {0};
@@ -586,7 +588,7 @@ log_redrawdetail ()
 int
 InitPages ()
 {
-   if (user_prefs && user_prefs->logfile == NULL)
+   if (user_prefs == NULL || user_prefs->logfile == NULL)
 	return -1;
 
    curlog = OpenLogFile (user_prefs->logfile);
